@@ -11,12 +11,13 @@
 
 #pragma once
 
-#include <QAbstractItemModel>
-
-#include "kleo_export.h"
-
 #include "keylist.h"
 #include "keylistmodelinterface.h"
+#include "kleo_export.h"
+
+#include <Libkleo/KeyGroup>
+
+#include <QAbstractItemModel>
 
 #include <vector>
 
@@ -28,15 +29,27 @@ class Key;
 namespace Kleo
 {
 
-class KLEO_EXPORT AbstractKeyListModel : public QAbstractItemModel
-                                       , public KeyListModelInterface
+class KLEO_EXPORT DragHandler
+{
+public:
+    virtual ~DragHandler()
+    {
+    }
+    virtual QMimeData *mimeData(const QModelIndexList &indexes) const = 0;
+    virtual Qt::ItemFlags flags(const QModelIndex &index) const = 0;
+    virtual QStringList mimeTypes() const = 0;
+};
+
+class KLEO_EXPORT AbstractKeyListModel : public QAbstractItemModel, public KeyListModelInterface
 {
     Q_OBJECT
 public:
     enum ItemType {
-        Keys = 0x01,
+        // clang-format off
+        Keys   = 0x01,
         Groups = 0x02,
-        All = Keys | Groups
+        All    = Keys | Groups,
+        // clang-format on
     };
     Q_DECLARE_FLAGS(ItemTypes, ItemType)
 
@@ -59,12 +72,15 @@ public:
     QModelIndex index(const KeyGroup &group) const override;
     QModelIndex index(const KeyGroup &group, int col) const;
 
+    void setDragHandler(const std::shared_ptr<DragHandler> &dragHandler);
+
 Q_SIGNALS:
     void rowAboutToBeMoved(const QModelIndex &old_parent, int old_row);
     void rowMoved(const QModelIndex &new_parent, int new_row);
 
 public Q_SLOTS:
-    void setKeys(const std::vector<GpgME::Key> &keys);
+    // extraOrigins is a list of origins that will be considered if the origin in the key is OriginUnknown. The indexes of keys and extraOrigins must match.
+    void setKeys(const std::vector<GpgME::Key> &keys, const std::vector<GpgME::Key::Origin> &extraOrigins = {});
     /* Set this to set all or only secret keys from the keycache. */
     void useKeyCache(bool value, Kleo::KeyList::Options options);
     QModelIndex addKey(const GpgME::Key &key);
@@ -99,11 +115,15 @@ public:
     void setRemarkKeys(const std::vector<GpgME::Key> &remarkKeys);
     std::vector<GpgME::Key> remarkKeys() const;
 
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
+    QStringList mimeTypes() const override;
+    QMimeData *mimeData(const QModelIndexList &indexes) const override;
+
 protected:
     bool modelResetInProgress();
 
 private:
-    QVariant data(const GpgME::Key &key, int column, int role) const;
+    QVariant data(const GpgME::Key &key, int row, int column, int role) const;
     QVariant data(const KeyGroup &group, int column, int role) const;
 
     virtual GpgME::Key doMapToKey(const QModelIndex &index) const = 0;
@@ -125,7 +145,6 @@ private:
     QScopedPointer<Private> const d;
 };
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(AbstractKeyListModel::ItemTypes)
+
 }
-
-Q_DECLARE_OPERATORS_FOR_FLAGS(Kleo::AbstractKeyListModel::ItemTypes)
-
