@@ -199,8 +199,9 @@ void Kleo::KeyRequester::updateKeys()
             continue;
         }
         const QString fpr = QLatin1StringView(it->primaryFingerprint());
-        labelTexts.push_back(fpr.right(8));
-        toolTipText += fpr.right(8) + QLatin1StringView(": ");
+        const QString keyID = QString::fromLatin1(it->keyID());
+        labelTexts.push_back(keyID);
+        toolTipText += keyID + QLatin1StringView(": ");
         if (const char *uid = it->userID(0).id()) {
             if (it->protocol() == GpgME::OpenPGP) {
                 toolTipText += QString::fromUtf8(uid);
@@ -236,7 +237,7 @@ static void showKeyListError(QWidget *parent, const GpgME::Error &err)
         "<p><b>%1</b></p></qt>",
         Formatting::errorAsString(err));
 
-    KMessageBox::error(parent, msg, i18n("Key Listing Failed"));
+    KMessageBox::error(parent, msg, i18nc("@title:window", "Key Listing Failed"));
 }
 #endif // __KLEO_UI_SHOW_KEY_LIST_ERROR_H__
 
@@ -269,7 +270,7 @@ void Kleo::KeyRequester::startKeyListJob(const QStringList &fingerprints)
             KMessageBox::error(this,
                                i18n("The OpenPGP backend does not support listing keys. "
                                     "Check your installation."),
-                               i18n("Key Listing Failed"));
+                               i18nc("@title:window", "Key Listing Failed"));
         } else {
             connect(job, &KeyListJob::result, this, &SigningKeyRequester::slotKeyListResult);
             connect(job, &KeyListJob::nextKey, this, &SigningKeyRequester::slotNextKey);
@@ -291,7 +292,7 @@ void Kleo::KeyRequester::startKeyListJob(const QStringList &fingerprints)
             KMessageBox::error(this,
                                i18n("The S/MIME backend does not support listing keys. "
                                     "Check your installation."),
-                               i18n("Key Listing Failed"));
+                               i18nc("@title:window", "Key Listing Failed"));
         } else {
             connect(job, &KeyListJob::result, this, &SigningKeyRequester::slotKeyListResult);
             connect(job, &KeyListJob::nextKey, this, &SigningKeyRequester::slotNextKey);
